@@ -18,27 +18,31 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+use std::collections::HashMap;
 use std::collections::HashSet;
 use std::path::PathBuf;
 
+use nucliadb_protos::nodereader;
+use nucliadb_protos::utils;
 use uuid::Uuid;
 
 use crate::metrics::vectors::MergeSource;
 use crate::prelude::*;
-use crate::protos::*;
 use crate::query_language::BooleanExpression;
 use crate::Channel;
 use crate::IndexFiles;
+use nucliadb_protos::noderesources;
 
 pub type VectorsReaderPointer = Box<dyn VectorReader>;
 pub type VectorsWriterPointer = Box<dyn VectorWriter>;
-pub type ProtosRequest = VectorSearchRequest;
-pub type ProtosResponse = VectorSearchResponse;
+pub type ProtosRequest = nodereader::VectorSearchRequest;
+pub type ProtosResponse = nodereader::VectorSearchResponse;
 
 #[derive(Debug, Clone, Copy)]
 pub struct MergeParameters {
     pub max_nodes_in_merge: usize,
     pub segments_before_merge: usize,
+    pub maximum_deleted_entries: usize,
 }
 
 pub struct MergeContext {
@@ -48,7 +52,7 @@ pub struct MergeContext {
 
 #[derive(Clone)]
 pub struct VectorConfig {
-    pub similarity: VectorSimilarity,
+    pub similarity: utils::VectorSimilarity,
     pub path: PathBuf,
     pub channel: Channel,
     pub shard_id: String,
@@ -83,6 +87,7 @@ pub trait VectorReader: std::fmt::Debug + Send + Sync {
     fn search(&self, request: &ProtosRequest, context: &VectorsContext) -> NodeResult<ProtosResponse>;
     fn stored_ids(&self) -> NodeResult<Vec<String>>;
     fn count(&self) -> NodeResult<usize>;
+    fn needs_update(&self) -> NodeResult<bool>;
 }
 
 pub trait VectorWriter: std::fmt::Debug + Send + Sync {
@@ -92,9 +97,65 @@ pub trait VectorWriter: std::fmt::Debug + Send + Sync {
 
     fn prepare_merge(&self, parameters: MergeParameters) -> NodeResult<Option<Box<dyn MergeRunner>>>;
     fn record_merge(&mut self, merge_result: Box<dyn MergeResults>, source: MergeSource) -> NodeResult<MergeMetrics>;
-    fn set_resource(&mut self, resource: &Resource) -> NodeResult<()>;
-    fn delete_resource(&mut self, resource_id: &ResourceId) -> NodeResult<()>;
+    fn set_resource(&mut self, resource: ResourceWrapper) -> NodeResult<()>;
+    fn delete_resource(&mut self, resource_id: &noderesources::ResourceId) -> NodeResult<()>;
     fn garbage_collection(&mut self) -> NodeResult<()>;
     fn force_garbage_collection(&mut self) -> NodeResult<()>;
     fn reload(&mut self) -> NodeResult<()>;
 }
+
+pub struct ResourceWrapper<'a> {
+    resource: &'a noderesources::Resource,
+    vectorset: Option<String>,
+}
+
+impl<'a> From<&'a noderesources::Resource> for ResourceWrapper<'a> {
+    fn from(value: &'a noderesources::Resource) -> Self {
+        Self {
+            resource: value,
+            vectorset: None,
+        }
+    }
+}
+
+impl<'a> ResourceWrapper<'a> {
+    pub fn new_vectorset_resource(resource: &'a noderesources::Resource, vectorset: &str) -> Self {
+        Self {
+            resource,
+            vectorset: Some(vectorset.to_string()),
+        }
+    }
+
+    pub fn id(&self) -> &String {
+        &self.resource.shard_id
+    }
+
+    pub fn fields(&self) -> impl Iterator<Item = (&String, impl Iterator<Item = ParagraphVectors>)> {
+        self.resource.paragraphs.iter().map(|(field_id, paragraphs_wrapper)| {
+            let sentences_iterator = paragraphs_wrapper.paragraphs.iter().filter_map(|(_paragraph_id, paragraph)| {
+                let sentences = if let Some(vectorset) = &self.vectorset {
+                    // indexing a vectorset, we should return only paragraphs from this vectorset.
+                    // If vectorset is not found, we'll skip this paragraph
+                    paragraph.vectorsets_sentences.get(vectorset).map(|x| &x.sentences)
+                } else {
+                    // Default vectors index (no vectorset)
+                    Some(&paragraph.sentences)
+                };
+                sentences.map(|s| ParagraphVectors {
+                    vectors: s,
+                    labels: &paragraph.labels,
+                })
+            });
+            (field_id, sentences_iterator)
+        })
+    }
+
+    pub fn sentences_to_delete(&self) -> impl Iterator<Item = &str> {
+        self.resource.paragraphs_to_delete.iter().map(|paragraph_id| paragraph_id.as_str())
+    }
+}
+
+pub struct ParagraphVectors<'a> {
+    pub vectors: &'a HashMap<String, noderesources::VectorSentence>,
+    pub labels: &'a Vec<String>,
+}
