@@ -139,6 +139,10 @@ impl VectorReader for VectorReaderService {
 
         Ok(result)
     }
+
+    fn needs_update(&self) -> NodeResult<bool> {
+        Ok(self.index.needs_update()?)
+    }
 }
 
 impl TryFrom<Neighbour> for DocumentScored {
@@ -182,12 +186,12 @@ mod tests {
 
     use nucliadb_core::protos::resource::ResourceStatus;
     use nucliadb_core::protos::{
-        IndexParagraph, IndexParagraphs, Resource, ResourceId, VectorSentence, VectorSimilarity, VectorsetSentences,
+        IndexParagraph, IndexParagraphs, Resource, ResourceId, VectorSentence, VectorsetSentences,
     };
-    use nucliadb_core::Channel;
     use tempfile::TempDir;
 
     use super::*;
+    use crate::config::{Similarity, VectorConfig, VectorType};
     use crate::service::writer::VectorWriterService;
 
     #[test]
@@ -195,11 +199,11 @@ mod tests {
         let dir = TempDir::new().unwrap();
         let shard_path = dir.path().join("vectors");
         let vsc = VectorConfig {
-            similarity: VectorSimilarity::Cosine,
-            path: shard_path.clone(),
-            channel: Channel::EXPERIMENTAL,
-            shard_id: "abc".into(),
+            similarity: Similarity::Cosine,
             normalize_vectors: false,
+            vector_type: VectorType::DenseF32 {
+                dimension: 3,
+            },
         };
         let raw_sentences = [
             ("DOC/KEY/1/1".to_string(), vec![1.0, 3.0, 4.0]),
@@ -256,8 +260,8 @@ mod tests {
             ..Default::default()
         };
         // insert - delete - insert sequence
-        let mut writer = VectorWriterService::create(vsc).unwrap();
-        writer.set_resource(&resource).unwrap();
+        let mut writer = VectorWriterService::create(&shard_path, "abc".into(), vsc).unwrap();
+        writer.set_resource((&resource).into()).unwrap();
 
         let reader = VectorReaderService::open(&shard_path).unwrap();
         let mut request = VectorSearchRequest {
@@ -285,11 +289,11 @@ mod tests {
         let dir = TempDir::new().unwrap();
         let shard_path = dir.path().join("vectors");
         let vsc = VectorConfig {
-            similarity: VectorSimilarity::Cosine,
-            path: shard_path.clone(),
-            channel: Channel::EXPERIMENTAL,
-            shard_id: "abc".into(),
+            similarity: Similarity::Cosine,
             normalize_vectors: false,
+            vector_type: VectorType::DenseF32 {
+                dimension: 3,
+            },
         };
         let raw_sentences = [
             ("DOC/KEY/1/1".to_string(), vec![1.0, 3.0, 4.0]),
@@ -346,8 +350,8 @@ mod tests {
             ..Default::default()
         };
         // insert - delete - insert sequence
-        let mut writer = VectorWriterService::create(vsc).unwrap();
-        let res = writer.set_resource(&resource);
+        let mut writer = VectorWriterService::create(&shard_path, "abc".into(), vsc).unwrap();
+        let res = writer.set_resource((&resource).into());
         assert!(res.is_ok());
         let reader = VectorReaderService::open(&shard_path).unwrap();
         let request = VectorSearchRequest {
@@ -414,11 +418,11 @@ mod tests {
         let dir = TempDir::new().unwrap();
         let shard_path = dir.path().join("vectors");
         let vsc = VectorConfig {
-            similarity: VectorSimilarity::Cosine,
-            path: shard_path.clone(),
-            channel: Channel::EXPERIMENTAL,
-            shard_id: "abc".into(),
+            similarity: Similarity::Cosine,
             normalize_vectors: false,
+            vector_type: VectorType::DenseF32 {
+                dimension: 3,
+            },
         };
         let raw_sentences =
             [("DOC/KEY/1/1".to_string(), vec![1.0, 2.0, 3.0]), ("DOC/KEY/1/2".to_string(), vec![1.0, 2.0, 3.0])];
@@ -470,8 +474,8 @@ mod tests {
             shard_id: "DOC".to_string(),
             ..Default::default()
         };
-        let mut writer = VectorWriterService::create(vsc).unwrap();
-        let res = writer.set_resource(&resource);
+        let mut writer = VectorWriterService::create(&shard_path, "abc".into(), vsc).unwrap();
+        let res = writer.set_resource((&resource).into());
         assert!(res.is_ok());
         let reader = VectorReaderService::open(&shard_path).unwrap();
         let request = VectorSearchRequest {
