@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU Affero General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+use crate::config::VectorConfig;
 use crate::data_point::{self, DataPointPin, Elem, LabelDictionary};
 use crate::data_point_provider::garbage_collector;
 use crate::data_point_provider::writer::Writer;
@@ -27,8 +28,7 @@ use nucliadb_core::metrics::request_time;
 use nucliadb_core::metrics::vectors::MergeSource;
 use nucliadb_core::prelude::*;
 use nucliadb_core::protos::prost::Message;
-use nucliadb_core::protos::resource::ResourceStatus;
-use nucliadb_core::protos::{Resource, ResourceId};
+use nucliadb_core::protos::ResourceId;
 use nucliadb_core::tracing::{self, *};
 use nucliadb_core::vectors::MergeMetrics;
 use nucliadb_core::vectors::*;
@@ -103,10 +103,10 @@ impl VectorWriter for VectorWriterService {
 
     #[measure(actor = "vectors", metric = "set_resource")]
     #[tracing::instrument(skip_all)]
-    fn set_resource(&mut self, resource: &Resource) -> NodeResult<()> {
+    fn set_resource(&mut self, resource: nucliadb_core::vectors::ResourceWrapper) -> NodeResult<()> {
         let time = Instant::now();
 
-        let id = resource.resource.as_ref().map(|i| &i.shard_id);
+        let id = resource.id();
         debug!("{id:?} - Updating main index");
         let v = time.elapsed().as_millis();
         debug!("{id:?} - Creating elements for the main index: starts {v} ms");
@@ -114,27 +114,25 @@ impl VectorWriter for VectorWriterService {
         let temporal_mark = SystemTime::now();
         let mut lengths: HashMap<usize, Vec<_>> = HashMap::new();
         let mut elems = Vec::new();
-        let normalize_vectors = self.index.metadata().normalize_vectors;
-        if resource.status != ResourceStatus::Delete as i32 {
-            for (field_id, field_paragraphs) in resource.paragraphs.iter() {
-                for paragraph in field_paragraphs.paragraphs.values() {
-                    let mut inner_labels = paragraph.labels.clone();
-                    inner_labels.push(field_id.clone());
-                    let labels = LabelDictionary::new(inner_labels);
+        let normalize_vectors = self.index.config().normalize_vectors;
+        for (field_id, field_paragraphs) in resource.fields() {
+            for paragraph in field_paragraphs {
+                let mut inner_labels = paragraph.labels.clone();
+                inner_labels.push(field_id.clone());
+                let labels = LabelDictionary::new(inner_labels);
 
-                    for (key, sentence) in paragraph.sentences.iter().clone() {
-                        let key = key.to_string();
-                        let labels = labels.clone();
-                        let vector = if normalize_vectors {
-                            utils::normalize_vector(&sentence.vector)
-                        } else {
-                            sentence.vector.clone()
-                        };
-                        let metadata = sentence.metadata.as_ref().map(|m| m.encode_to_vec());
-                        let bucket = lengths.entry(vector.len()).or_default();
-                        elems.push(Elem::new(key, vector, labels, metadata));
-                        bucket.push(field_id);
-                    }
+                for (key, sentence) in paragraph.vectors.iter().clone() {
+                    let key = key.to_string();
+                    let labels = labels.clone();
+                    let vector = if normalize_vectors {
+                        utils::normalize_vector(&sentence.vector)
+                    } else {
+                        sentence.vector.clone()
+                    };
+                    let metadata = sentence.metadata.as_ref().map(|m| m.encode_to_vec());
+                    let bucket = lengths.entry(vector.len()).or_default();
+                    elems.push(Elem::new(key, vector, labels, metadata));
+                    bucket.push(field_id);
                 }
             }
         }
@@ -151,13 +149,13 @@ impl VectorWriter for VectorWriterService {
         if !elems.is_empty() {
             let location = self.index.location();
             let time = Some(temporal_mark);
-            let similarity = self.index.metadata().similarity;
+            let similarity = self.index.config().similarity;
             let data_point_pin = DataPointPin::create_pin(location)?;
             data_point::create(&data_point_pin, elems, time, similarity)?;
             self.index.add_data_point(data_point_pin)?;
         }
 
-        for to_delete in &resource.sentences_to_delete {
+        for to_delete in resource.sentences_to_delete() {
             let key_as_bytes = to_delete.as_bytes();
             self.index.record_delete(key_as_bytes, temporal_mark);
         }
@@ -217,18 +215,12 @@ impl VectorWriterService {
     }
 
     #[tracing::instrument(skip_all)]
-    pub fn create(config: VectorConfig) -> NodeResult<Self> {
-        let path = std::path::Path::new(&config.path);
+    pub fn create(path: &Path, shard_id: String, config: VectorConfig) -> NodeResult<Self> {
         if path.exists() {
             Err(node_error!("Shard does exist".to_string()))
         } else {
-            let index_metadata = IndexMetadata {
-                similarity: config.similarity.into(),
-                channel: config.channel,
-                normalize_vectors: config.normalize_vectors,
-            };
             Ok(VectorWriterService {
-                index: Writer::new(path, index_metadata, config.shard_id)?,
+                index: Writer::new(path, config, shard_id)?,
                 path: path.to_path_buf(),
             })
         }
@@ -251,23 +243,24 @@ impl VectorWriterService {
 mod tests {
     use nucliadb_core::protos::resource::ResourceStatus;
     use nucliadb_core::protos::{
-        IndexParagraph, IndexParagraphs, Resource, ResourceId, VectorSentence, VectorSimilarity, VectorsetSentences,
+        IndexParagraph, IndexParagraphs, Resource, ResourceId, VectorSentence, VectorsetSentences,
     };
-    use nucliadb_core::Channel;
     use std::collections::HashMap;
     use tempfile::TempDir;
 
+    use crate::config::{Similarity, VectorType};
+
     use super::*;
 
     #[test]
     fn test_new_vector_writer() {
         let dir = TempDir::new().unwrap();
         let vsc = VectorConfig {
-            similarity: VectorSimilarity::Cosine,
-            path: dir.path().join("vectors"),
-            channel: Channel::EXPERIMENTAL,
-            shard_id: "abc".into(),
+            similarity: Similarity::Cosine,
             normalize_vectors: false,
+            vector_type: VectorType::DenseF32 {
+                dimension: 3,
+            },
         };
         let raw_sentences = [
             ("DOC/KEY/1/1".to_string(), vec![1.0, 3.0, 4.0]),
@@ -323,12 +316,12 @@ mod tests {
             ..Default::default()
         };
         // insert - delete - insert sequence
-        let mut writer = VectorWriterService::create(vsc).unwrap();
-        let res = writer.set_resource(&resource);
+        let mut writer = VectorWriterService::create(&dir.path().join("vectors"), "abc".into(), vsc).unwrap();
+        let res = writer.set_resource(nucliadb_core::vectors::ResourceWrapper::from(&resource));
         assert!(res.is_ok());
         let res = writer.delete_resource(&resource_id);
         assert!(res.is_ok());
-        let res = writer.set_resource(&resource);
+        let res = writer.set_resource(nucliadb_core::vectors::ResourceWrapper::from(&resource));
         assert!(res.is_ok());
     }
 
@@ -336,11 +329,11 @@ mod tests {
     fn test_get_segments() {
         let dir = TempDir::new().unwrap();
         let vsc = VectorConfig {
-            similarity: VectorSimilarity::Cosine,
-            path: dir.path().join("vectors"),
-            channel: Channel::EXPERIMENTAL,
-            shard_id: "abc".into(),
+            similarity: Similarity::Cosine,
             normalize_vectors: false,
+            vector_type: VectorType::DenseF32 {
+                dimension: 3,
+            },
         };
         let resource_id = ResourceId {
             shard_id: "DOC".to_string(),
@@ -392,12 +385,12 @@ mod tests {
             ..Default::default()
         };
         // insert - delete - insert sequence
-        let mut writer = VectorWriterService::create(vsc).unwrap();
-        let res = writer.set_resource(&resource);
+        let mut writer = VectorWriterService::create(&dir.path().join("vectors"), "abc".into(), vsc).unwrap();
+        let res = writer.set_resource(nucliadb_core::vectors::ResourceWrapper::from(&resource));
         assert!(res.is_ok());
         let res = writer.delete_resource(&resource_id);
         assert!(res.is_ok());
-        let res = writer.set_resource(&resource);
+        let res = writer.set_resource(nucliadb_core::vectors::ResourceWrapper::from(&resource));
         assert!(res.is_ok());
 
         let segments = writer.get_segment_ids().unwrap();
